
#include <stdint.h>
#include <stdbool.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <avr/io.h>
#include <util/delay.h>
#include <avr/pgmspace.h>
#include <avr/interrupt.h>

#include <button.h>
#include <uart.h>
#include <i2c.h>
#include <adc.h>
#include <disp.h>
#include <relay.h>
#include <timer.h>

#include <contr.h>

int main(void) {
    uart_init();
    i2c_init();
    uartio_init();
    disp_init();

    adc_init();
    timer0_init();

    atten_init();
    ampl_init();
    filter10m_init();
    filter20m_init();
    filter40m_init();
    filter80m_init();
    buzzer_init();
    fan_init();
    ptt_init();

    button_init();
    button_reset();

    ampl_off();
    atten_off();
    filter10m_off();
    filter20m_off();
    filter40m_off();
    filter80m_off();
    buzzer_off();
    fan_off();

    contr_init();
    contr_setup();
    sei();
    contr_main();
    return 0;
}
